.. _components_concept:

====================
What is a Component?
====================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------

 - Components represent aspects and behaviors of simulants
 - Components are classes
 - ``configuration_defaults``
 - An ``__init__`` trick for generic components.
 - The ``setup`` method.

   - Load data here
   - No simulants exist yet

 - Write a good ``__repr__``
